@@ -30,7 +30,7 @@ module Async
 	# Raised if a timeout occurs on a specific Fiber. Handled gracefully by {Task}.
 	class TimeoutError < RuntimeError
 	end
-
+	
 	# An asynchronous, cooperatively scheduled event reactor.
 	class Reactor < Node
 		extend Forwardable
@@ -58,10 +58,10 @@ module Async
 			end
 		end
 		
-		def initialize
-			super
+		def initialize(parent = nil, selector: NIO::Selector.new)
+			super(parent)
 			
-			@selector = NIO::Selector.new
+			@selector = selector
 			@timers = Timers::Group.new
 			
 			@ready = []
@@ -76,6 +76,10 @@ module Async
 		# @attr stopped [Boolean]
 		attr :stopped
 		
+		def stopped?
+			@stopped
+		end
+		
 		def_delegators :@timers, :every, :after
 		
 		# Start an asynchronous task within the specified reactor. The task will be
@@ -102,10 +106,9 @@ module Async
 			return task
 		end
 		
-		def register(*args)
-			monitor = @selector.register(*args)
-			
-			monitor.value = Fiber.current
+		def register(io, interest, value = Fiber.current)
+			monitor = @selector.register(io, interest)
+			monitor.value = value
 			
 			return monitor
 		end
@@ -165,21 +168,18 @@ module Async
 					interval = 0
 				end
 				
-				# Async.logger.debug{"[#{self} Pre] Updating #{@children.count} children..."}
+				# Async.logger.debug(self) {"Updating #{@children.count} children..."}
 				# As timeouts may have been updated, and caused fibers to complete, we should check this.
 				
 				# If there is nothing to do, then finish:
-				# Async.logger.debug{"[#{self}] @children.empty? = #{@children.empty?} && interval #{interval.inspect}"}
 				if !interval && self.finished?
 					return initial_task
 				end
 				
-				# Async.logger.debug{"Selecting with #{@children.count} fibers interval = #{interval.inspect}..."}
+				# Async.logger.debug(self) {"Selecting with #{@children.count} fibers interval = #{interval.inspect}..."}
 				if monitors = @selector.select(interval)
 					monitors.each do |monitor|
-						if fiber = monitor.value
-							fiber.resume # if fiber.alive?
-						end
+						monitor.value.resume
 					end
 				end
 			end until @stopped
